# Advanced Utils

## 使用

```
pip install advanced-utils -U
```

## 安装依赖

```
pip install setuptools wheel twine
```

## 单元测试

```
python setup.py test
```

## 打包

```
python setup.py sdist bdist_wheel
```

## 上传

```
twine upload dist/*

# jy01264313
# !@#zx19880427
```